(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(require('jquery')) :
  typeof define === 'function' && define.amd ? define(['jquery'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.$));
}(this, (function ($$1) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var $__default = /*#__PURE__*/_interopDefaultLegacy($$1);

  var version = "2.1.0";

  /**
   * These are additional pseudos for the jQuery selector.
   * It's possible to add more in the object "window.Furtive.pseudos" if needed.
   */
  var pseudos = {
    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    equals: function (e, index, parts) {
      return $(e).val() === parts[3];
    },

    /**
     * @param e
     * @return {boolean}
     */
    filled: function (e) {
      return $(e).val().length > 0;
    },

    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    contains: function (e, index, parts) {
      return $(e).val().indexOf(parts[3]) > -1;
    },

    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    gt: function (e, index, parts) {
      return +$(e).val() > +parts[3];
    },

    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    gte: function (e, index, parts) {
      return +$(e).val() >= +parts[3];
    },

    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    lt: function (e, index, parts) {
      return +$(e).val() < +parts[3];
    },

    /**
     * @param e
     * @param index
     * @param parts
     * @return {boolean}
     */
    lte: function (e, index, parts) {
      return +$(e).val() <= +parts[3];
    },
  };

  /**
   * This function will bind all the main watcher to all the container elements.
   *
   * @private
   */
  let Furtive = function ($container) {
    const condition = "data-furtive-condition";
    const conjunction = "data-furtive-conjunction";
    const disabled = "data-furtive-disabled";
    const required = "data-furtive-required";

    // Use an internal copy of jQuery at this point (to avoid conflict with other pseudos)
    const _jQuery = $__default['default'];
    _jQuery.extend($__default['default'].expr[":"], window.Furtive.pseudos);

    let watcher = function () {
      $container.find("[" + condition + "]").each(function (k, item) {
        let cond = $__default['default'](item).attr(condition);
        let conj = $__default['default'](item).attr(conjunction);
        let $item = $__default['default'](item);

        if (cond !== undefined && cond.length) {
          // Extract selectors from the given condition
          let selectors = cond.match(/('.*?'|[^',]+)+(?=\s*|\s*$)/g);
          let matches = 0;

          for (let i = 0, l = selectors.length; i < l; i++) {
            if (_jQuery(selectors[i]).length) {
              matches++;
            }
          }

          let visible =
            conj && conj.toLowerCase() === "and"
              ? matches === selectors.length
              : matches > 0;

          $item.toggle(visible);

          if (false !== window.Furtive.disableHidden) {
            $item.find(":input").each(function (z, input) {
              let $input = $__default['default'](input);

              // Stash the old disabled and require properties and apply new one
              if (!visible) {
                if ($input.attr(disabled) === undefined) {
                  $input.attr(disabled, $input.prop("disabled"));
                  $input.prop("disabled", true);
                }

                if ($input.attr(required) === undefined) {
                  $input.attr(required, $input.prop("required"));
                  $input.prop("required", false);
                }
              }

              // Re-apply the old disabled and required properties
              if (visible) {
                $input.prop("disabled", $input.attr(disabled) === "true");
                $input.removeAttr(disabled);

                $input.prop("required", $input.attr(required) === "true");
                $input.removeAttr(required);
              }
            });
          }
        }
      });
    };

    $container
      .find(":checkbox, :radio, :file, select")
      .change(watcher)
      .triggerHandler("change");

    $container.find(":text, textarea").keyup(watcher).triggerHandler("keyup");
  };

  /**
   * Initialize the Furtive plugin on the selection.
   *
   * @public
   */
  $__default['default'].fn.furtive = function () {
    if (this.length > 1) {
      this.each(function () {
        $__default['default'](this).furtive();
      });
    }

    if (this.length === 1) {
      Furtive($__default['default'](this));
    }
  };

  /**
   * Ensure the extension is now defined if it wasn't previously.
   * Auto binding is set to TRUE by default.
   * Disable hidden <input> elements is set to TRUE by default.
   * Custom "pseudos" can be added as well.
   *
   * @public
   */
  if ("undefined" === typeof window.Furtive) {
    window.Furtive = {
      autoBind: true,
      disableHidden: true,
      pseudos,
      version,
    };
  }

  /**
   * Auto-binding can be prevented by settings the "window.Furtive.autoBind" value to FALSE.
   */
  if (false !== window.Furtive.autoBind) {
    $__default['default'](function () {
      const el = $__default['default']("[data-furtive-watch]");
      return el.length && el.furtive();
    });
  }

})));
//# sourceMappingURL=jquery.furtive.js.map
